Molten Core
molten-core provides the foundational domain models, traits, and types for the Molten
Document and Workflow Management system. This crate defines the contracts that all other
Molten crates implement and depend upon.
This crate is under active development and is not yet stable. If this crate has been abandoned, please message me and we can discuss ownership transfer.
Re-exports
pub use document::Document;pub use field::FieldBuilder;pub use field::FieldDefinition;pub use field::FieldType;pub use form::FormBuilder;pub use form::FormDefinition;pub use workflow::Phase;pub use workflow::Transition;pub use workflow::WorkflowBuilder;pub use workflow::WorkflowDefinition;
Modules
- document
- This module defines the
Documentstruct, which represents a concrete instance of a form. - field
- This module defines the core structures for managing the definition and behavior of individual fields within a form.
- form
- This module defines the core structures for managing
FormDefinitions, which serve as blueprints for documents within the Molten system. - workflow
- This module defines the core structures for managing workflow definitions, which dictate the lifecycle and state transitions of documents within the Molten system.